@@ -4,7 +4,7 @@
 #include <clock.h>
 #include <init.h>
 #include <asm/armlinux.h>
-#include <generated/mach-types.h>
+#include <asm/mach-types.h>
 #include <mach/omap/devices.h>
 #include <mach/omap/omap4-silicon.h>
 #include <mach/omap/omap4-devices.h>
