@@ -12,7 +12,7 @@
 #include <environment.h>
 #include <mach/imx/imx6-regs.h>
 #include <asm/armlinux.h>
-#include <generated/mach-types.h>
+#include <asm/mach-types.h>
 #include <linux/phy.h>
 #include <asm/io.h>
 #include <asm/mmu.h>
