@@ -7,7 +7,7 @@
 #include <io.h>
 #include <gpio.h>
 #include <asm/armlinux.h>
-#include <generated/mach-types.h>
+#include <asm/mach-types.h>
 #include <mach/omap/omap4-silicon.h>
 #include <mach/omap/omap4-devices.h>
 #include <mach/omap/sdrc.h>
