@@ -220,7 +220,7 @@ static void atmci_setup_data(struct atmel_mci *host, struct mci_data *data)
 
 	host->data = data;
 
-	dev_dbg(host->hw_dev, "atmel_setup_data: nob=%d blksz=%d\n",
+	dev_vdbg(host->hw_dev, "atmel_setup_data: nob=%d blksz=%d\n",
 		nob, blksz);
 
 	atmci_writel(host, ATMCI_BLKR, ATMCI_BCNT(nob)
@@ -437,7 +437,7 @@ void atmci_get_cap(struct atmel_mci *host)
 	version = atmci_readl(host, ATMCI_VERSION) & 0x00000fff;
 	host->version = version;
 
-	dev_info(host->hw_dev, "version: 0x%x\n", version);
+	dev_dbg(host->hw_dev, "version: 0x%x\n", version);
 
 	host->caps.has_cfg_reg = 0;
 	host->caps.has_highspeed = 0;
